@@ -47,7 +47,7 @@ sub import {
 }
 
 
-our $VERSION = '0.0178';    # VERSION
+our $VERSION = '0.0179';    # VERSION
 
 1;
 
@@ -65,7 +65,7 @@ Evo - Evo - the next generation component-oriented development framework
 
 =head1 VERSION
 
-version 0.0178
+version 0.0179
 
 =head1 DESCRIPTION
 
@@ -94,6 +94,9 @@ It makes real thing that are considered impossible in other languages. For examp
 =item *
 Exception handling in pure perl: L<Evo::Eval>, "try catch" alternative. Like C<Try::Tiny>, but without it's bugs and much faster
 
+=item *
+L<Evo::Ee> - a component role that gives your component "EventEmitter" abilities
+
 =back
 
 =head1 SYNOPSYS
@@ -120,24 +123,25 @@ Used to make package header shorter
   :: => .. (append to parent)
   - => Evo (append to Evo)
 
-Import C<Evo::SomeComp> namespace
+=head2 shortcuts
 
-  use Evo '-SomeComp';
+Shortcuts are used to make life easily during code refactoring (and you module shorter) in L<Evo::Export> and L<Evo::Comp/"with">
 
-Import C<My::Ns::Foo::Rel>:
+C<-> is replaced by C<Evo>
 
-  package My::Ns::Foo;
-  use Evo ':Bar';
+  use Evo '-Promises promise';
 
-Import C<My::Ns::Bar>:
+C<:> and C<::> make sense in the package and depends on the package name where is used
 
-  package My::Ns::Foo;
-  use Evo '::Bar';
+C<:> means relative to the current module as a child
 
-You can split import by C<;>
+  package My::App;
+  use Evo ':Bar'; # My::App::Bar
 
-  package My::Ns::Foo;
-  use Evo ':Bar bar1; :Baz baz1; Other::Foo foo1';
+C<::> means as sibling (child of the parent of the current module)
+
+  package My::App;
+  use Evo '::Bar'; # My::Bar
 
 =head1 IMPORTS
 
