@@ -16,7 +16,7 @@ Evo::Comp
 
 =head1 VERSION
 
-version 0.0178
+version 0.0179
 
 =head1 DESCRIPTION
 
@@ -171,10 +171,21 @@ You can also return C<(0, "CustomError")> to provide more expressive explanation
   $foo->big(9);    # will die
   my $bar = My::Foo::new(big => 9);    # will die
 
-=head2 Code reuse
+=head1 Code reuse
 
 Instead of OO inheritance, wich suffers from fragile base class problem, C<Evo::Comp> provides L<Evo::Comp::Role>. This is a perfect choice for code reuse because of it's safety and flexibility. Look at L<Evo::Comp::Role> for more information
 
+=head2 with
+
+Load role and install all methods and attributes to the component. Supports L<Evo/"shortcuts">
+
+    package Person;
+    use Evo '-Comp *';
+
+    with ':LoudHuman', ':Human';
+
+Circular requirements can be solved by requiring roles in the single C<with>. See L<Evo::Comp::Role/"requires">
+
 =head1 AUTHOR
 
 alexbyk.com
