@@ -3,8 +3,7 @@ use Evo;
 use Evo::Export '*';
 use Carp 'croak';
 
-sub croak_bad_value : Export {
-  my ($value, $name, $msg) = @_;
+sub croak_bad_value($value, $name, $msg=undef) : Export {
   my $err = qq'Bad value "$value" for attribute "$name"';
   $err .= ": $msg" if $msg;
   croak $err;
@@ -24,7 +23,7 @@ Evo::Comp::Util
 
 =head1 VERSION
 
-version 0.0178
+version 0.0179
 
 =head1 AUTHOR
 
