@@ -78,7 +78,7 @@ Evo::Export
 
 =head1 VERSION
 
-version 0.0178
+version 0.0179
 
 =head1 DESCRIPTION
 
@@ -113,28 +113,7 @@ For convenient, you can load all above in one line
 
   use Evo '-Eval eval_try; -Promises promise, deferred';
 
-=head2 shortcuts
-
-You can you shortcuts: C<-> is replaced by C<Evo>
-
-  # the same, but shorter
-  use Evo '-Promises promise';
-
-And these make sense in the package and depends on the package name where is used
-
-C<:> means relative to the current module as a child
-
-  package My::App;
-  use Evo ':Bar'; # My::App::Bar
-
-C<::> means as sibling (child of the parent of the current module)
-
-  package My::App;
-  use Evo '::Bar'; # My::Bar
-
-C<*> means load all
-
-  use Evo '-Promises *';
+C<*> means load all. C<-> is a shortcut. See L<Evo/"shortcuts>
 
 =head2 what to import and how
 
