@@ -1,6 +1,8 @@
 package Evo::Util;
 use strict;
 use warnings;
+use experimental 'signatures';
+no warnings 'experimental::signatures';
 use Carp qw(carp croak);
 
 
@@ -17,22 +19,19 @@ sub debug { return unless $DEBUG; carp "[${\(caller)[0]}]: $_[0]"; }
 
 
 # usefull?
-sub find_caller_except {
-  my ($skip_ns, $i, $caller) = (shift);
+sub find_caller_except($skip_ns, $i, $caller) {
   while ($caller = (caller($i++))[0]) {
     return $caller if $caller ne $skip_ns;
   }
 }
 
-sub monkey_patch {
-  my ($pkg, %hash) = @_;
+sub monkey_patch($pkg, %hash) {
   no strict 'refs';    ## no critic
   *{"${pkg}::$_"} = $NAME->("${pkg}::$_", $hash{$_}) for keys %hash;
 }
 
 #todo: decide what to do with empty subroutins
-sub monkey_patch_silent {
-  my ($pkg, %hash) = @_;
+sub monkey_patch_silent($pkg, %hash) {
   no strict 'refs';    ## no critic
   no warnings 'redefine';
   my %restore;
@@ -45,41 +44,16 @@ sub monkey_patch_silent {
 }
 
 
-sub list_symbols {
-  my $pkg = shift;
+sub list_symbols($pkg) {
   no strict 'refs';    ##no critic
   grep { $_ =~ /^[a-zA-Z_]\w*$/ } keys %{"${pkg}::"};
 }
 
-sub undef_symbols {
-  my $ns = shift;
+sub undef_symbols($ns) {
   no strict 'refs';    ## no critic
   undef *{"${ns}::$_"} for list_symbols($ns);
 }
 
-sub stash_in_obj { stash(shift->{stash} ||= {}, @_); }
-
-sub stash_multi {
-  my $h = shift;
-  return $h unless @_;
-
-  my $group = shift;
-  return $h->{$group} unless @_;
-
-  return $h->{$group} && $h->{$group}{$_[0]} if @_ == 1;
-
-  my %hash = @_;
-  @{$h->{$group}}{(keys %hash)} = values %hash;
-  $h;
-}
-
-sub stash {
-  my $h = shift or croak "Not a hash reference";
-  return $h->{(shift)} if @_ == 1;
-  my %hash = @_;
-  @$h{(keys %hash)} = values %hash;
-  $h;
-}
 
 sub uniq {
   my %seen;
@@ -87,8 +61,7 @@ sub uniq {
 }
 
 # returns a subroutine than can pretend a code in the other package/file/line
-sub inject {
-  my %opts = @_;
+sub inject(%opts) {
   my ($package, $filename, $line, $code) = @opts{qw(package filename line code)};
 
   ## no critic
@@ -99,8 +72,7 @@ sub inject {
   );
 }
 
-sub find_subnames {
-  my ($pkg, $code) = @_;
+sub find_subnames($pkg, $code) {
   no strict 'refs';    ## no critic
   my %symbols = %{$pkg . "::"};
 
@@ -112,16 +84,14 @@ sub find_subnames {
 our $RX_PKG_NOT_FIRST = qr/[0-9A-Z_a-z]+(?:::[0-9A-Z_a-z]+)*/;
 our $RX_PKG           = qr/^[A-Z_a-z]$RX_PKG_NOT_FIRST*$/;
 
-sub _parent {
-  my ($caller, $rel) = @_;
+sub _parent($caller, $rel) {
   my @arr = split /::/, $caller;
   pop @arr;
   push @arr, $rel if $rel;
   join '::', @arr;
 }
 
-sub resolve_package {
-  my ($caller, $pkg) = @_;
+sub resolve_package($caller, $pkg) {
   return $pkg if $pkg =~ $RX_PKG;
 
   if ($pkg =~ /^\-($RX_PKG_NOT_FIRST)$/) {
@@ -152,7 +122,7 @@ Evo::Util
 
 =head1 VERSION
 
-version 0.0178
+version 0.0179
 
 =head1 DESCRIPTION
 
