@@ -3,10 +3,8 @@ use Carp 'croak';
 use Evo '-Eval *', '-Export *';
 
 
-sub w_eval_run : Export {
-  my $catch = shift or croak "Pass catch function";
-  sub {
-    my $next = shift;
+sub w_eval_run($catch) : Export {
+  sub($next) {
     sub {
       my $call = eval_want(wantarray, @_, $next);
       return $call->result if $call;
@@ -30,7 +28,7 @@ Evo::W::Eval
 
 =head1 VERSION
 
-version 0.0178
+version 0.0179
 
 =head1 AUTHOR
 
